e static method
Logs an error message with optional error object and stack trace.
Use for error events that might still allow the application to continue.
try {
await fetchData();
} catch (e, stack) {
Log.e('Failed to fetch data', error: e, stackTrace: stack);
}
Implementation
static void e(dynamic message, {Object? error, StackTrace? stackTrace}) =>
_logger.severe(_format(message), error, stackTrace);